@@ -5,10 +5,10 @@ from tcp2canopsis.connector import Connector
 from twisted.internet import reactor, endpoints
 
 
-def run_daemon(port, amqpuri):
+def run_daemon(port, amqpuri, token):
     server = 'tcp:{0}'.format(port)
 
-    factory = ConnectorFactory(amqpuri, Connector)
+    factory = ConnectorFactory(amqpuri, token, Connector)
     endpoint = endpoints.serverFromString(reactor, server)
     endpoint.listen(factory)
     reactor.run()
